@@ -3,10 +3,9 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.2009';
+our $VERSION = '0.2010';
 
 use Algorithm::Combinatorics qw(variations_with_repetition);
-use lib map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-Util);
 use MIDI::Util qw(dura_size set_time_signature);
 use Music::Duration;
 
@@ -31,7 +30,8 @@ sub BUILD {
 
     $self->score->control_change($self->channel, 91, $self->reverb);
 
-    $self->set_time_sig;
+    # Add a TS to the score but don't reset the beats if given
+    $self->set_time_sig( $self->signature, !$args->{beats} );
 }
 
 
@@ -44,9 +44,9 @@ has file      => ( is => 'ro', default => sub { 'MIDI-Drummer.mid' } );
 has bars      => ( is => 'ro', default => sub { 4 } );
 has score     => ( is => 'ro', default => sub { MIDI::Simple->new_score } );
 has signature => ( is => 'rw', default => sub { '4/4' });
-has beats     => ( is => 'rw' );
-has divisions => ( is => 'rw' );
-has counter   => ( is => 'rw', default => sub { 0 });
+has beats     => ( is => 'rw', default => sub { 4 }  );
+has divisions => ( is => 'rw', default => sub { 4 } );
+has counter   => ( is => 'rw', default => sub { 0 } );
 
 
 has click          => ( is => 'ro', default => sub { 'n33' } );
@@ -378,13 +378,14 @@ sub crescendo_roll {
 
 
 sub set_time_sig {
-    my $self = shift;
-    if (@_) {
-        $self->signature(shift);
+    my ($self, $signature, $set) = @_;
+    $self->signature($signature) if $signature;
+    $set //= 1;
+    if ($set) {
+        my ($beats, $divisions) = split /\//, $self->signature;
+        $self->beats($beats);
+        $self->divisions($divisions);
     }
-    my ($beats, $divisions) = split /\//, $self->signature;
-    $self->beats($beats);
-    $self->divisions($divisions);
     set_time_signature($self->score, $self->signature);
 }
 
@@ -464,7 +465,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.2009
+version 0.2010
 
 =head1 SYNOPSIS
 
@@ -578,11 +579,15 @@ B<beats> / B<divisions>
 
 =head2 beats
 
-Computed given the B<signature>.
+Computed from the B<signature>, if not given in the constructor.
+
+Default: C<4>
 
 =head2 divisions
 
-Computed given the B<signature>.
+Computed from the B<signature>.
+
+Default: C<4>
 
 =head2 counter
 
@@ -654,7 +659,8 @@ can be overridden with the B<electric_bass> (C<'n36'>).
 
   $d = MIDI::Drummer::Tiny->new(%arguments);
 
-Return a new C<MIDI::Drummer::Tiny> object.
+Return a new C<MIDI::Drummer::Tiny> object and add a time signature
+event to the score.
 
 =head2 note
 
@@ -802,10 +808,16 @@ rather than as a straight line.
 
 =head2 set_time_sig
 
+  $d->set_time_sig;
   $d->set_time_sig('5/4');
+  $d->set_time_sig( '5/4', 0 );
 
-Set the B<signature>, B<beats>, B<divisions>, and the B<score>
-C<time_signature> values based on the given string.
+Add a time signature event to the score, and reset the B<beats> and
+B<divisions> object attributes.
+
+If a ratio argument is given, set the B<signature> object attribute to
+it.  If the 2nd argument flag is C<0>, the B<beats> and B<divisions>
+are B<not> reset.
 
 =head2 sync
 
